@@ -162,6 +162,9 @@ xfce_titled_dialog_init (XfceTitledDialog *titled_dialog)
   titled_dialog->priv->headerbar = gtk_dialog_get_header_bar (GTK_DIALOG (titled_dialog));
   g_return_if_fail (GTK_IS_HEADER_BAR (titled_dialog->priv->headerbar));
 
+  /* Don't reserve vertical space for subtitles */
+  gtk_header_bar_set_has_subtitle (GTK_HEADER_BAR (titled_dialog->priv->headerbar), FALSE);
+
   /* Pack the window icon into the headerbar */
   titled_dialog->priv->icon = gtk_image_new ();
   gtk_header_bar_pack_start (GTK_HEADER_BAR (titled_dialog->priv->headerbar), titled_dialog->priv->icon);
